==> site24x7-0.3.91.tar.gz: site24x7-0.3.91/src/site24x7_plugin_helper/connector/request_client.py <==
import requests
from .models.model import ClientModel

class RequestClient(ClientModel):
    '''cache client is a client model that is used to store data in a cache file'''
    def __init__(self, *args, headers=None, auth=None, data=None **kwargs):
        self.dict = {}
        self.auth = auth
        self.data = data
        if not headers:
            self.headers = {'Content-Type': 'application/json'}
        elif isinstance(headers, dict):
            self.headers = headers
        else:
            raise Exception("headers must be a dict") from None
        super().__init__(self.dict, *args, **kwargs)

    def get(self, url, **kwargs):
        '''get the data from the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.get(url, headers=headers, data=data, auth=auth)

    def post(self, url, **kwargs):
        '''post the data to the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.post(url, headers=headers, data=data, auth=auth)

    def delete(self, url, **kwargs):
        '''delete the data from the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.delete(url, headers=headers, data=data, auth=auth)

    def put(self, url, **kwargs):
        '''put the data to the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.put(url, headers=headers, data=data, auth=auth)

==> site24x7-0.4.0.tar.gz: site24x7-0.4.0/src/site24x7_plugin_helper/connector/request_client.py <==
import requests
from .models.model import ClientModel

class RequestClient(ClientModel):
    '''cache client is a client model that is used to store data in a cache file'''
    def __init__(self, *args, headers=None, auth=None, data=None, **kwargs):
        self.dict = {}
        self.auth = auth
        self.data = data
        if not headers:
            self.headers = {'Content-Type': 'application/json'}
        elif isinstance(headers, dict):
            self.headers = headers
        else:
            raise Exception("headers must be a dict") from None
        super().__init__(self.dict, *args, **kwargs)

    def get(self, url, **kwargs):
        '''get the data from the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.get(url, headers=headers, data=data, auth=auth)

    def post(self, url, **kwargs):
        '''post the data to the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.post(url, headers=headers, data=data, auth=auth)

    def delete(self, url, **kwargs):
        '''delete the data from the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.delete(url, headers=headers, data=data, auth=auth)

    def put(self, url, **kwargs):
        '''put the data to the url'''
        headers = kwargs.get('headers', self.headers)
        data = kwargs.get('data', self.data)
        auth = kwargs.get('auth', self.auth)
        return requests.put(url, headers=headers, data=data, auth=auth)
